@@ -25,7 +25,7 @@ This package implements the Shut CLI.
 
 from shut import __version__
 from shut.model import Project
-from nr.proxy import Proxy
+from nr.proxy import proxy
 
 import click
 import logging
@@ -33,8 +33,8 @@ import os
 import warnings
 import sys
 
-context = Proxy(lambda: click.get_current_context().obj)
-project = Proxy(lambda: click.get_current_context().obj['project'])
+context: click.Context = proxy(lambda: click.get_current_context().obj)
+project: Project = proxy(lambda: click.get_current_context().obj['project'])
 
 
 @click.group()
