@@ -29,6 +29,8 @@ from databind.core import datamodel, field
 from nr.stream import chain, concat
 
 from shut.utils.ast import load_module_members
+from shut.utils.fs import get_file_in_directory
+from .author import Author
 from .abstract import AbstractProjectModel
 from .linter import LinterConfiguration
 from .publish import PublishConfiguration
@@ -41,26 +43,6 @@ class PackageError(Exception):
   pass
 
 
-def _get_file_in_directory(directory: str, prefix: str, preferred: List[str]) -> Optional[str]:
-  """
-  Returns a file in *directory* that is either in the *preferred* list or starts with
-  specified *prefix*.
-  """
-
-  choices = []
-  for name in sorted(os.listdir(directory)):
-    if name in preferred:
-      break
-    if name.startswith(prefix):
-      choices.append(name)
-  else:
-    if choices:
-      return choices[0]
-    return None
-
-  return os.path.join(directory, name)
-
-
 @datamodel
 class InstallConfiguration:
   @datamodel
@@ -75,6 +57,21 @@ class InstallConfiguration:
 
   hooks: InstallHooks = field(default_factory=InstallHooks)
 
+  #: A value for the `--index-url` option to pass to Pip when using `shut pkg install`.
+  index_url: Optional[str] = field(altname='index-url', default=None)
+
+  #: A list of URLs to pass to Pip via the `--extra-index-url` option when using
+  #: `shut pkg install`.
+  extra_index_urls: List[str] = field(altname='extra-index-urls', default_factory=list)
+
+  def get_pip_args(self) -> List[str]:
+    result = []
+    if self.index_url:
+      result += ['--index-url', self.index_url]
+    for url in self.extra_index_urls:
+      result += ['--extra-index-url', url]
+    return result
+
 
 @datamodel
 class PackageModel(AbstractProjectModel):
@@ -165,21 +162,11 @@ class PackageModel(AbstractProjectModel):
     if self.readme:
       return os.path.abspath(os.path.join(directory, self.readme))
 
-    return _get_file_in_directory(
+    return get_file_in_directory(
       directory=directory,
       prefix='README.',
       preferred=['README.md', 'README.rst', 'README.txt', 'README'])
 
-  def get_license_file(self) -> Optional[str]:
-    """
-    Returns the absolute path to the LICENSE file for this package.
-    """
-
-    return _get_file_in_directory(
-      directory=os.path.dirname(self.filename),
-      prefix='LICENSE.',
-      preferred=['LICENSE', 'LICENSE.txt', 'LICENSE.rst', 'LICENSE.md'])
-
   def get_py_typed_file(self) -> Optional[str]:
     if not self.typed:
       return None
@@ -192,13 +179,38 @@ class PackageModel(AbstractProjectModel):
       return self.project.monorepo.publish
     return self.publish
 
+  def get_license(self) -> Optional[str]:
+    if self.license:
+      return self.license
+    if self.project.monorepo:
+      return self.project.monorepo.license
+    return None
+
+  def get_author(self) -> Optional[Author]:
+    if self.author:
+      return self.author
+    if self.project.monorepo:
+      return self.project.monorepo.author
+    return None
+
+  def get_url(self) -> Optional[str]:
+    if self.url:
+      return self.url
+    if self.project.monorepo:
+      return self.project.monorepo.url
+    return None
+
   # AbstractProjectModel
 
   def get_name(self) -> str:
     return self.name
 
   def get_version(self) -> Optional[Version]:
-    return self.version
+    if self.version:
+      return self.version
+    if self.project.monorepo and self.project.monorepo.release.single_version:
+      return self.project.monorepo.get_version()
+    return None
 
   def get_tag(self, version: Version) -> str:
     tag_format = self.release.tag_format
@@ -206,6 +218,15 @@ class PackageModel(AbstractProjectModel):
       tag_format = '{name}@' + tag_format
     return tag_format.format(name=self.name, version=version)
 
+  def get_license_file(self, inherit: bool = False) -> Optional[str]:
+    if inherit and self.project.monorepo and (not self.license or
+        self.license == self.project.monorepo.license):
+      filename = self.project.monorepo.get_license_file()
+      if filename:
+        return os.path.join(self.project.monorepo.get_directory(), filename)
+
+    return super().get_license_file(False)
+
 
 class PythonPackageMetadata:
   """
